use warnings;
use strict;
use Test::More tests => 9;

use POWER::Utils qw( UpdateHash );


my ($in, $out, $wait, $main);

$out    = UpdateHash();
is_deeply($out, {},       "without params");

$in     = {};
$out    = UpdateHash($in);
is_deeply($in, $out,      "empty hash");
is("$in", "$out",           "same hash");

$out    = UpdateHash($in, {});
is_deeply($in, $out,      "don't change");

$wait   = {
    s1=>1, s2=>2, a0=>[], a1=>[1], a2=>[2,3],
    h0=>{}, h1=>{qwe=>"asd"}, h2=>{1=>2,3=>4}
    };
$out    = UpdateHash({}, { s1 => 1, s2 => 2 });
UpdateHash($out, { a0 => [], a1 => [1], a2 => [2, 3] });
UpdateHash($out, { h0 => {}, h1 => {qwe=>"asd"}, h2 => {1=>2, 3=>4} });
is_deeply($out, $wait,    "3 updates");

$wait->{a2} = [4,5];
$wait->{h2}{3} = 44;
$out    = UpdateHash($out, { a2 => [4, 5], h2 => {3=>44} });
is_deeply($out, $wait,    "replace array and update hash");

$wait->{a1} = {hash=>"new"};
UpdateHash($out, { a1 => {hash=>"new"} });
is_deeply($out, $wait,    "replace array with hash");

$wait->{h1} = [15];
UpdateHash($out, { h1 => [15] });
is_deeply($out, $wait,    "replace hash with array");

# from documentation

$main = {};
UpdateHash( $main, {
    PARAM1 => "value1",
    PARAM2 => 15,
    });
UpdateHash( $main, {
    PARAM2 => 123,
    PARAM3 => {
        DATA1 => "value31",
        DATA2 => "value32",
        },
    });
UpdateHash( $main, {
    PARAM3 => {
        DATA2 => "newvalue32",
        },
    });
$wait = {
    PARAM1 => "value1",
    PARAM2 => 123,
    PARAM3 => {
        DATA1 => "value31",
        DATA2 => "newvalue32",
        },
    };
is_deeply($main, $wait,   "complex example");

